bibliotheca Augustana

<<< Einführung
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge liet ## Handschrift C ## um 1230 ## Hohenems-Laßbergische Handschrift ## nach der digitalen Edition ## von Hermann Reichert
___________________________________________________
###### 1 | Aventivre von den Nibelungen
###### 2 | Auentv von Sivride wie der erzogen wart
###### 3 | Auentv wie Sivrit ze Wormze chome
###### 4 | Auentv wie Sivrit mit den Sahsen streit
###### 5 | Auentv wie Sivrit Chriemh' alreste ersach
###### 6 | Auentv wie sich Gunther gein Islande hin ze Prvnh' bereite
###### 7 | Auentv wie Gunther ze Islande mit sinen gesellen chom
###### 8 | Auentv wie Sifrit nah den Nibelungen sinen rechen fvor
###### 9 | Auentv wie Sivrit ze Wormez in botschefte fvor
###### 10 | Auentv wie der kunec Gunther zu Wormze mit frov Prvnh' prvtte
###### 11 | Auentv wie Sifrit sin wip heim ze lande fvrte vñ wie er sit da heime brvotten
###### 12 | Auentv wie Gvnther Sivriden vñ Chriemh' ze Wormze
###### 13 | Auentv wie Chriemh' mit ir man zer hochgecite fvr
###### 14 | Auentv wie die chvniginne mit ander zerwrfen
###### 15 | Auentv wie ze Wormze widersaget
###### 16 | Auentv wie Sivrit ermort wart
###### 17 | Auentv wie Ch'r ir man klagte vñ wie man in begrvp
###### 18 | Auenture wie Chriemh' da bestvnt vñ ir sweher dannen reit
###### 19 | Auentv wie der Nibelunge hort ze Wormze braht wart
###### 20 | Auentv wie der chvnic Ezele nah froen Ch' ze Wormze sinen boten sande
###### 21 | Auentv wie Chriemhilt von Wormze schiet do si gein den Hvnen fvor
###### 22 | Auentv wie Chriemh' vñ Ezele brvten in der stat ze wienne
###### 23 | Auentv wie der kunec Ezele vñ div frowe C nach ir frivnden ze Wormez sande
###### 24 | Auentv wie die boten ze Rine quamen vñ wie si danne schieden
###### 25 | Auentewor wie sich die chünig von den Hewonenn houbenn
###### 26 | abentewer wy sy mit Elsen vnd Gelpfraten striten vnd wye in gelang
###### 27 | Auentv wie der marchrave die kunige mit ir rechen in sin hvs enpfie vñ wier ir sit pflach
###### 28 | Auenture wie die Nibelunge ze Ezeln bvrge chomen vñ wie si da enpfangen wrden
###### 29 | Aventv wie Hagene vñ Volker vor Chriemh' sal sazen
###### 30 | Auentvre wie die kvnige mit ir rechen slafen giengen vñ wie in do geschach
###### 31 | Auentv wie die Herren ze kirchen giengen
###### 32 | Auentv wie Bloedel mit Danchwart an der herberge streit
###### 33 | Auentv wie Danchwart div maer ze hove sinen herren braht
###### 34 | keine Überschrift [A: Wie si toten abe wurfen]
###### 35 | Auentv wie Irinch mit Hagenen streit vñ wie im sit an im gelanch
###### 36 | Auentv wie drie kvnige mit Ezele vñ mit ir swester vmbe die Svone reiten
###### 37 | Auentv wie Rvdeger erslagen wart
###### 38 | Auentv wie des herren Dietriches rechen alle wrden erslagen
###### 39 | Auentv wie der herre Dietrich Guntehern vñ Hagenen betwanch ## fol. 1r ## fol. 34v ## fol. 35r ## fol. 89r

<<< Einführung